@@ -196,34 +196,8 @@ class CrossCorrelationGraph(object):
 
         # Make graph not dense
         else:
-            # Initialise non-dense graph
-            graph = nx.Graph()
-
-            # Fill non-dense graph with nodes
-            for node in self.graph:
-                # Loop over network destinations for each node in graph
-                for destination in self.mapping.get(node):
-                    # Add destination as a separate node
-                    graph.add_node(destination)
-
-            # Fill non-dense graph with edges
-            for node in self.graph:
-                # Loop over network destinations for each node in graph
-                for source in self.mapping.get(node):
-                    # Add all edges in between nodes
-                    for destination in self.mapping.get(node):
-                        # No self-loops
-                        if source == destination: continue
-                        # Add all source-destination edges
-                        graph.add_edge(source, destination, weight=1)
-
-                    # Add all edges to other nodes
-                    for connected in nx.neighbors(self.graph, node):
-                        # Get edge get_edge_data
-                        data = self.graph.get_edge_data(node, connected)
-                        # Get all destinations
-                        for destination in self.mapping.get(connected):
-                            graph.add_edge(source, destination, data=data)
+            # Get non-dense graph
+            graph = self.unpack()
 
             # Transform network destinations to human readable format
             # Initialise mapping
@@ -259,6 +233,55 @@ class CrossCorrelationGraph(object):
             nx.write_gexf(graph, outfile)
 
 
+    def unpack(self):
+        """Unpack an optimized graph.
+            Unpacks a dense graph (see IMPORTANT note at graph) into a graph
+            where every NetworkDestination has its own node. Note that these
+            graphs can get very large with lots of edges, therefore, for manual
+            inspection it is recommended to use the regular graph instead.
+
+            Returns
+            -------
+            graph : nx.Graph
+                Unpacked graph
+            """
+        # Initialise non-dense graph
+        graph = nx.Graph()
+
+        # Fill non-dense graph with nodes
+        for node in self.graph:
+            # Loop over network destinations for each node in graph
+            for destination in self.mapping.get(node):
+                # Add destination as a separate node
+                graph.add_node(destination)
+
+        # Fill non-dense graph with edges
+        for node in self.graph:
+            # Loop over network destinations for each node in graph
+            for source in self.mapping.get(node):
+                # Add all edges in between nodes
+                for destination in self.mapping.get(node):
+                    # No self-loops
+                    if source == destination: continue
+                    # Add all source-destination edges
+                    graph.add_edge(source, destination, weight=1)
+
+                # Add all edges to other nodes
+                for connected in nx.neighbors(self.graph, node):
+                    # Get edge get_edge_data
+                    data = self.graph.get_edge_data(node, connected)
+                    # Get all destinations
+                    for destination in self.mapping.get(connected):
+                        graph.add_edge(
+                            source,
+                            destination,
+                            weight=data.get('weight')
+                        )
+
+        # Return result
+        return graph
+
+
     ########################################################################
     #                      Compute cross correlation                       #
     ########################################################################
@@ -287,7 +310,7 @@ class CrossCorrelationGraph(object):
         activity = self.activity(cluster)
         # Get inverted mapping
         mapping = dict()
-        for destination, active in activity.items():
+        for destination, active in sorted(activity.items(), key=lambda x: x[0].identifier):
             mapping[frozenset(active)] =\
                 mapping.get(frozenset(active), set()) | set([destination])
 
